@@ -479,9 +479,9 @@ class Reshape(nn.Module):
 class Unsequeeze(nn.Module):
     """for Unsequeeze
     """
-    def __init__(self, **kwargs):
+    def __init__(self, dim):
         super(Unsequeeze, self).__init__()
-        self.dim= kwargs['dim']
+        self.dim = dim
 
     def forward(self, x):
         return x.unsqueeze(self.dim)
